
***--------------------------------------------------------------------------***
 //* Chade and Lindenlaub
 //* Risky Matching
 //* December 2020
 //* Replication Codes
 //*
 //*** Description of file.
 //*
 //* Loads DOT data to obtain Jobs' Cognitive Skill Requirements (early period).
 //*
 //* This code prepares our measure of the cognitive task content per census 
 //* occupation, which is the variable MATH in the DOT data (for compatibility
 //* with the ONET measures for later period).
 //*
 //* Note: To reproduce results, random number generator needs to be re-set.
***--------------------------------------------------------------------------***


clear  		all
capture 	log close
set 		more off 
 
cd 			"~/Replication_Codes_submit/Occupational_Tasks/DOT"

set			seed 1984


***--PREPARATION-------------------------------------------------------------***

* import original data from Autor et al.(2003)
use 		"Original_Data_Autor_et_al.(2003)/dot77-8090.dta", clear

* keep variable MATH
keep 		math occ8090

* normalize
foreach 	v of varlist math {
su 			`v'
replace 	`v' = (`v' - r(min))/(r(max)-r(min))
}
		
save 		dot.dta, replace		



	
***--MERGE CENSUS 1990-------------------------------------------------------***

* merge with crosswalk to link to census data in 1990
use 		"Original_Data_Autor_et_al.(2003)/occ90.dta", clear
keep 		occ8090 occ90
merge 		m:1 occ8090 using dot.dta
keep 		if _merge==3
erase 		dot.dta

* generate percentiles
cumul       math, generate(y)

* rename & tidy up
rename 		occ90 occ1990
keep 		occ1990 y math

* save
save 		dot_final.dta, replace // 493 occ's












