
***--------------------------------------------------------------------------***
 //* Chade and Lindenlaub
 //* Risky Matching
 //* December 2020
 //* Replication Codes
 //* 
 //*
 //*** Description of file.
 //*
 //* Construct G and Q distribution in both periods.
 //*
 //*
 //* Note: To reproduce results, random number generator needs to be re-set.
***--------------------------------------------------------------------------***
 

clear  		all
capture 	log close
set 		more off 
 
cd 			"~/Replication_Codes_submit/Wage_Data"
global		onet "~/Replication_Codes_submit/Occupational_Tasks/ONET"
global		dot "~Replication_Codes_submit/Occupational_Tasks/DOT"
global		testscores "~/Replication_Codes_submit/Test_Scores/Original_Data_Altonji_et_al.(2009)"

set 		seed 1984



***--------------------------------------------------------------------------***
 //* G distribution
***--------------------------------------------------------------------------***


***--EARLY PERIOD------------------------------------------------------------***

* import data
use 		cps_data.dta, clear

* select early period
keep 		if year>=1979 & year <=1981

* merge with y-data (from the DOT)
merge 		m:1 occ1990 using "$dot/dot_final.dta"
keep 		if _merge==3 
drop 		_merge 

*normalize onetscores
foreach 	v of varlist y {
su 			`v'
replace 	`v' = (`v' - r(min))/(r(max)-r(min))
}
	
* G distribution
gen 		freq_y = 1
collapse 	(count) freq_y, by(y)
list
outsheet 	using "G_early.csv", comma replace

* expand y according to frequencies
expand		freq_y
keep 		y
sort		y
outsheet 	using "G_expanded_early.csv", comma replace

* draw random sample (to shrink estimation sample)
bsample		50000
sort 		y
outsheet 	using "G_expanded_sample_early.csv", comma replace




***--LATER PERIOD------------------------------------------------------------***

* load data
use 		cps_data.dta, clear

* select later period
keep 		if year>=2015 & year <= 2017

* merge with y-data (from the ONET)
merge 		m:1 occ1990 using "$onet/onet_final.dta"
keep 		if _merge==3 
drop 		_merge 

*normalize onetscores
foreach 	v of varlist y {
su 			`v'
replace 	`v' = (`v' - r(min))/(r(max)-r(min))
}
	
* G distribution
gen 		freq_y = 1
collapse 	(count) freq_y, by(y)
list
outsheet 	using "G_later.csv", comma replace

* expand y according to frequencies
expand		freq_y
keep 		y
sort		y
outsheet 	using "G_expanded_later.csv", comma replace

* draw random sample (to shrink estimation sample)
bsample		50000
sort 		y
outsheet 	using "G_expanded_sample_later.csv", comma replace




***--------------------------------------------------------------------------***
 //* Q distribution
***--------------------------------------------------------------------------***


***--EARLY PERIOD------------------------------------------------------------***

* load the data
use 		"$testscores/afqt_adjusted_final.dta", clear 

keep 		if sample ==0 
keep 		afqt_std weight
sort 		afqt_std

* normalize between 0 and 1
quietly 	su afqt_std
replace 	afqt_std = (afqt_std - r(min))/(r(max)-r(min))

* save
outsheet 	using "Q_early.csv", comma replace




***--LATER PERIOD------------------------------------------------------------***

* load the data
use 		"$testscores/afqt_adjusted_final.dta", clear

keep 		if sample ==1  
keep 		afqt_std weight
sort 		afqt_std

* normalize between 0 and 1
quietly 	su afqt_std
replace 	afqt_std = (afqt_std - r(min))/(r(max)-r(min))

* save
outsheet 	using "Q_later.csv", comma replace







